/*
Copyright (C) 2011 by Blazing Games Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
package com.blazinggames.cgl.atlas
{
	import flash.display.Bitmap;
	import flash.display.BitmapData;
	import flash.display.Sprite;
	
	/**
	 * Displays an Image Atlas Clip (which can be changed at any time).
	 *  
	 * @author Billy D. Spelchan
	 */	
	public class AtlasSprite 
	extends Sprite
	{		
// ***** VARIABLES *****
		
		private var _atlas:ImageAtlas;
		private var _bitmap:Bitmap;
		private var _clip:ClipInfo;
		
// ***** CONSTRUCTOR *****
		
		/**
		 * Sets up an image atlas sprite to the desired clip.
		 *  
		 * @param atlas The source Image Atlas.
		 * @param clipID The name of the clip to be shown.
		 * 
		 */		
		public function AtlasSprite(atlas:ImageAtlas, clipID:String)
		{
			super();
			_atlas = atlas;
			setClip(clipID);
		}

// ***** METHODS - display and playback *****
		
		/**
		 * Changes the image clip to the indicated clip.
		 * 
		 * @param clipID The name of the image clip to be shown 
		 */		
		public function setClip(clipID:String):void
		{
			if ( (_clip == null) || (_clip.clipID != clipID) ) {
				_clip = _atlas.getClip(clipID);
				if (_clip == null) _clip = new ClipInfo();
			}
			if (_bitmap == null) {
				_bitmap = new Bitmap(_clip.bitmapData);
				addChild(_bitmap);
			} else {
				_bitmap.bitmapData = _clip.bitmapData;
			}
			
			_bitmap.x = 0 - _clip.origin.x;
			_bitmap.y = 0 - _clip.origin.y;
		}
		
	}
}